pub struct Backend {
pub client: Client,
pub http_client: Arc<dyn HttpClient>,
/* private fields */
}Fields
client: Clienthttp_client: Arc<dyn HttpClient>Implementations
Sourceimpl Backend
impl Backend
Sourcepub fn new(client: Client, http_client: Box<dyn HttpClient>) -> Self
pub fn new(client: Client, http_client: Box<dyn HttpClient>) -> Self
Creates a new Backend with a Ureq http client and UTF16 encoding.
The workspaces are created empty.
Sourcepub fn update_diagnostics_for_url_and_dependent(&self, file_url: Url)
pub fn update_diagnostics_for_url_and_dependent(&self, file_url: Url)
Take a document with the profided file url and generate diagnostics for it. Then do the same thing with documents that depend on this one.
Panics
If an documents path is not convertable into an URL
Sourcepub fn load_dependencies(&self, path: &Path) -> JoinHandle<()>
pub fn load_dependencies(&self, path: &Path) -> JoinHandle<()>
Loads all documents that can be reached by this internal document path
Panics
When the path is not a file path
Sourcepub async fn wait_for_indexing(&self)
pub async fn wait_for_indexing(&self)
Waits for all background indexing tasks to complete. Useful for benchmarks to ensure no background work interferes with measurements.